import 'package:flutter/material.dart';
import 'CssStyle.dart';

class StyledWidget extends StatelessWidget {
  final Widget child;
  final dynamic style;
  final dynamic visible;
  final dynamic childCounts;

  StyledWidget({this.child, this.style, this.visible, this.childCounts});

  @override
  Widget build(BuildContext context) {
    return LayoutBuilder(
        builder: (BuildContext context, BoxConstraints constraints) {
          double maxWidth = constraints.maxWidth;
          double maxHeight = constraints.maxHeight;

          double screenWidth=MediaQuery.of(context).size.width;

          Style styleUsed=chooseFrom(style, screenWidth);
          bool visibleUsed=chooseFrom(visible, screenWidth);
          List<int> childCountsUsed=chooseFrom(childCounts, screenWidth).cast<int>();

          print(visibleUsed);
          print(childCountsUsed);

          double width = styleUsed.width.toPX(context, constraintParentSize: maxWidth);
          double height = styleUsed.height.toPX(context,
              constraintParentSize: maxHeight, constraintWidth: width);
          BoxDecoration backgroundDecoration = styleUsed.backgroundDecoration;

          double marginLeft =
          styleUsed.marginLeft.toPX(context, constraintParentSize: maxWidth);
          double marginRight =
          styleUsed.marginRight.toPX(context, constraintParentSize: maxWidth);
          double marginTop =
          styleUsed.marginTop.toPX(context, constraintParentSize: maxHeight);
          double marginBottom =
          styleUsed.marginBottom.toPX(context, constraintParentSize: maxHeight);
          double paddingLeft =
          styleUsed.paddingLeft.toPX(context, constraintParentSize: maxWidth);
          double paddingRight =
          styleUsed.paddingRight.toPX(context, constraintParentSize: maxWidth);
          double paddingTop =
          styleUsed.paddingTop.toPX(context, constraintParentSize: maxHeight);
          double paddingBottom =
          styleUsed.paddingBottom.toPX(context, constraintParentSize: maxHeight);

          return Container(
            width: width,
            height: height,
            margin: EdgeInsets.only(
                left: marginLeft,
                right: marginRight,
                top: marginTop,
                bottom: marginBottom),
            padding: EdgeInsets.only(
                left: paddingLeft,
                right: paddingRight,
                top: paddingTop,
                bottom: paddingBottom),
            decoration: backgroundDecoration,
            child: child,
          );
        });
  }
}